;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "paren-face" "20251101.2048"
  "A face for parentheses in lisp modes."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/paren-face"
  :commit "b121bc08ecb0c11a89705ed9f77c5343e2baec04"
  :revdesc "b121bc08ecb0"
  :keywords '("faces" "lisp")
  :authors '(("Jonas Bernoulli" . "emacs.paren-face@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.paren-face@jonas.bernoulli.dev")))
